==> php-3.0.10.tar.gz: php-3.0.10/stack.h <==
/* 
   +----------------------------------------------------------------------+
   | PHP HTML Embedded Scripting Language Version 3.0                     |
   +----------------------------------------------------------------------+
   | Copyright (c) 1997-1999 PHP Development Team (See Credits file)      |
   +----------------------------------------------------------------------+
   | This program is free software; you can redistribute it and/or modify |
   | it under the terms of one of the following licenses:                 |
   |                                                                      |
   |  A) the GNU General Public License as published by the Free Software |
   |     Foundation; either version 2 of the License, or (at your option) |
   |     any later version.                                               |
   |                                                                      |
   |  B) the PHP License as published by the PHP Development Team and     |
   |     included in the distribution in the file: LICENSE                |
   |                                                                      |
   | This program is distributed in the hope that it will be useful,      |
   | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
   | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
   | GNU General Public License for more details.                         |
   |                                                                      |
   | You should have received a copy of both licenses referred to here.   |
   | If you did not, or have any questions about PHP licensing, please    |
   | contact core@php.net.                                                |
   +----------------------------------------------------------------------+
   | Authors: Andi Gutmans <andi@php.net>                                 |
   |          Zeev Suraski <bourbon@netvision.net.il>                     |
   +----------------------------------------------------------------------+
 */


/* $Id: stack.h,v 1.14 1999/01/01 17:58:52 zeev Exp $ */


#ifndef _STACK_H
#define _STACK_H

typedef struct {
	int top, max;
	void **elements;
} Stack;


#define STACK_BLOCK_SIZE 64

extern int stack_init(Stack *stack);
extern int stack_push(Stack *stack, void *element, int size);
extern int stack_top(Stack *stack, void **element);
extern int stack_del_top(Stack *stack);
extern int stack_int_top(Stack *stack);
extern int stack_is_empty(Stack *stack);
extern int stack_destroy(Stack *stack);

#endif

==> php-3.0.13.tar.gz: php-3.0.13/stack.h <==
/* 
   +----------------------------------------------------------------------+
   | PHP HTML Embedded Scripting Language Version 3.0                     |
   +----------------------------------------------------------------------+
   | Copyright (c) 1997-2000 PHP Development Team (See Credits file)      |
   +----------------------------------------------------------------------+
   | This program is free software; you can redistribute it and/or modify |
   | it under the terms of one of the following licenses:                 |
   |                                                                      |
   |  A) the GNU General Public License as published by the Free Software |
   |     Foundation; either version 2 of the License, or (at your option) |
   |     any later version.                                               |
   |                                                                      |
   |  B) the PHP License as published by the PHP Development Team and     |
   |     included in the distribution in the file: LICENSE                |
   |                                                                      |
   | This program is distributed in the hope that it will be useful,      |
   | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
   | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
   | GNU General Public License for more details.                         |
   |                                                                      |
   | You should have received a copy of both licenses referred to here.   |
   | If you did not, or have any questions about PHP licensing, please    |
   | contact core@php.net.                                                |
   +----------------------------------------------------------------------+
   | Authors: Andi Gutmans <andi@php.net>                                 |
   |          Zeev Suraski <bourbon@netvision.net.il>                     |
   +----------------------------------------------------------------------+
 */


/* $Id: stack.h,v 1.16 2000/01/01 04:44:07 sas Exp $ */


#ifndef _STACK_H
#define _STACK_H

typedef struct {
	int top, max;
	void **elements;
} Stack;


#define STACK_BLOCK_SIZE 64

extern int php3i_stack_init(Stack *stack);
extern int php3i_stack_push(Stack *stack, void *element, int size);
extern int php3i_stack_top(Stack *stack, void **element);
extern int php3i_stack_del_top(Stack *stack);
extern int php3i_stack_int_top(Stack *stack);
extern int php3i_stack_is_empty(Stack *stack);
extern int php3i_stack_destroy(Stack *stack);

#endif
